@@ -57,11 +57,12 @@ class Authorization(object):
 
         token = utils.generate_random_vschar(self.token_length)
         refresh_token = utils.generate_random_vschar(self.token_length)
-
+        token_data = kwargs
+        token_data['username'] = username
         token_key = self.storage.save(token=token, token_type='access_token',
-                                      client_id=None, data=kwargs, expire=self.expire)
+                                      client_id=None, data=token_data, expire=self.expire)
         refresh_key = self.storage.save(token=refresh_token, token_type='refresh_token',
-                                        client_id=None, data=kwargs, expire=None)
+                                        client_id=None, data=token_data, expire=None)
         return {
             "access_token": token,
             "token_type": self.token_type,
